---
title: About
publish_date: May 10, 2015
special: true
---

<!-- TODO: portrait -->

Here are a few facts of an autobiographical nature:

* I write words, at least some of the time.
* I run Python, at least some of the time.

My PGP key fingerprint looks a little like:

`ABCD 92F2 EDE7 BEEF DEED A3CF 4567 4756 ED87 1234`
